import classnames from 'classnames';
import React from 'react';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-audio-horn {\n  width: 0.93333rem;\n  height: 0.74667rem;\n  display: inline-block;\n  background-size: contain;\n  background-image: url('https://cdn.llscdn.com/sprout/assets/20190116/icSound3@2x.png');\n  background-repeat: no-repeat;\n}\n.ph-audio-horn.is-pad {\n  width: 0.3418rem;\n  height: 0.27344rem;\n}\n.ph-audio-horn .audio-el {\n  display: none;\n}\n.ph-audio-horn.on-play {\n  -webkit-animation: 1s audio-horn-animation infinite;\n          animation: 1s audio-horn-animation infinite;\n}\n@-webkit-keyframes audio-horn-animation {\n  0% {\n    background-image: url('https://cdn.llscdn.com/sprout/assets/20190116/icSound1@2x.png');\n  }\n  50% {\n    background-image: url('https://cdn.llscdn.com/sprout/assets/20190116/icSound2@2x.png');\n  }\n  100% {\n    background-image: url('https://cdn.llscdn.com/sprout/assets/20190116/icSound3@2x.png');\n  }\n}\n@keyframes audio-horn-animation {\n  0% {\n    background-image: url('https://cdn.llscdn.com/sprout/assets/20190116/icSound1@2x.png');\n  }\n  50% {\n    background-image: url('https://cdn.llscdn.com/sprout/assets/20190116/icSound2@2x.png');\n  }\n  100% {\n    background-image: url('https://cdn.llscdn.com/sprout/assets/20190116/icSound3@2x.png');\n  }\n}\n";
styleInject(css);

var Status;
(function (Status) {
    Status[Status["PLAY"] = 0] = "PLAY";
    Status[Status["STOP"] = 1] = "STOP";
})(Status || (Status = {}));
class AudioHorn extends React.Component {
    constructor() {
        super(...arguments);
        this.audio = null;
        this.state = { status: Status.STOP };
        this.clickHandler = () => {
            const { status } = this.state;
            const { onClick } = this.props;
            const audio = this.audio;
            if (status === Status.PLAY) {
                audio.pause();
                this.setState({ status: Status.STOP });
            }
            else {
                audio.currentTime = 0;
                audio.play();
                this.setState({ status: Status.PLAY });
            }
            if (onClick)
                onClick();
        };
    }
    componentDidMount() {
        setTimeout(_ => {
            this.audio.addEventListener('ended', () => {
                this.setState({ status: Status.STOP });
            });
        }, 0);
    }
    render() {
        const { url, isPad, className } = this.props;
        return (React.createElement("div", { className: classnames('ph-audio-horn', className, {
                'on-play': this.state.status === Status.PLAY,
                'is-pad': isPad
            }), onClick: this.clickHandler },
            React.createElement("audio", { className: "audio-el", ref: el => (this.audio = el), src: url })));
    }
}

export default AudioHorn;
