import classnames from 'classnames';
import React, { PureComponent } from 'react';
import ClickFeedback from 'rmc-feedback';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-button {\n  touch-action: manipulation;\n  display: block;\n  height: 1.44rem;\n  line-height: 1.44rem;\n  font-size: 0.48rem;\n  font-weight: 400;\n  color: #fff;\n  text-align: center;\n  border-radius: 0.74667rem;\n  background-color: #ffb400;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  word-break: break-word;\n  white-space: nowrap;\n}\n.ph-button-large-br {\n  border-radius: 0.8rem;\n}\n.ph-button-inline {\n  display: inline-block;\n  padding: 0 0.4rem;\n}\n.ph-button-active {\n  position: relative;\n}\n.ph-button-active::after {\n  content: '';\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  background: rgba(0, 0, 0, 0.1);\n  border-radius: inherit;\n}\n.ph-button.ph-button-disabled {\n  color: #fff;\n  background-color: #d8d8d8;\n}\n.ph-button-danger {\n  color: #fff;\n  background-color: #ff3333;\n}\n.ph-button-ghost {\n  color: #ffb400;\n  border: 1PX solid #ffb400;\n  background-color: transparent;\n}\n.ph-button-ghost.ph-button-active {\n  background-color: rgba(79, 203, 25, 0.1);\n}\n.ph-button-ghost.ph-button-active::after {\n  content: none;\n}\n.ph-button-ghost.ph-button-disabled {\n  color: #d8d8d8;\n  border-color: #d8d8d8;\n  background-color: transparent;\n}\n.ph-button-icon {\n  display: -webkit-box;\n  display: flex;\n  -webkit-box-pack: center;\n  justify-content: center;\n  -webkit-box-align: center;\n  align-items: center;\n}\n.ph-button-icon > .ph-button-icon {\n  margin-right: 0.5em;\n}\n.ph-button-pad {\n  height: 0.52734rem;\n  line-height: 0.52734rem;\n  border-radius: 0.27344rem;\n  font-size: 0.17578rem;\n}\n";
styleInject(css);

const prefixCls = 'ph-button';
class PhButton extends PureComponent {
    constructor() {
        super(...arguments);
        this.onClick = () => {
            const { disabled, onClick } = this.props;
            if (disabled)
                return;
            // tslint:disable-next-line
            onClick && onClick();
        };
    }
    render() {
        const { className, inline, children, disabled, type, br, isPad, ...props } = this.props;
        const { onClick } = this;
        const cls = classnames(prefixCls, className, {
            [`${prefixCls}-ghost`]: type === 'ghost',
            [`${prefixCls}-danger`]: type === 'danger',
            [`${prefixCls}-large-br`]: br === 'large',
            [`${prefixCls}-disabled`]: disabled,
            [`${prefixCls}-inline`]: inline,
            'ph-button-pad': isPad
        });
        return (React.createElement(ClickFeedback, { activeClassName: `${prefixCls}-active`, disabled: disabled },
            React.createElement("a", Object.assign({ role: "button", className: cls }, props, { onClick: onClick }), children)));
    }
}
PhButton.defaultProps = {
    type: 'primary',
    br: 'small',
    disabled: false,
    inline: false
};

export default PhButton;
