import classnames from 'classnames';
import React, { PureComponent } from 'react';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-click-anime {\n  display: inline-block;\n  -webkit-transform-origin: center;\n          transform-origin: center;\n  -webkit-transition: -webkit-transform 0.5s;\n  transition: -webkit-transform 0.5s;\n  transition: transform 0.5s;\n  transition: transform 0.5s, -webkit-transform 0.5s;\n  will-change: transform;\n}\n";
styleInject(css);

class ClickAnime extends PureComponent {
    constructor() {
        super(...arguments);
        this.el = null;
        this.state = { touchIn: false };
        this.touchStart = () => {
            this.setState({ touchIn: true });
        };
        this.touchEnd = () => {
            this.setState({ touchIn: false });
        };
    }
    render() {
        const { children, className, startTransform, endTransform, selected, onClick } = this.props;
        return (React.createElement("div", { className: classnames('ph-click-anime', className), style: {
                transform: this.state.touchIn || selected ? endTransform : startTransform
            }, onClick: e => {
                if (onClick)
                    onClick(e);
            }, ref: el => (this.el = el), onTouchStart: this.touchStart, onTouchEnd: this.touchEnd, onTouchCancel: this.touchEnd }, children));
    }
}
ClickAnime.defaultProps = {
    startTransform: 'scale(1)',
    endTransform: 'scale(1.08)',
    selected: false
};

export default ClickAnime;
