import classnames from 'classnames';
import React from 'react';
import { PHONE_RATIO, PAD_RATIO } from '../common';
import Imager from '../imager';
import parseParams from '../parse-params';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-empty-record {\n  text-align: center;\n  padding: 3.78667rem 0 0.53333rem;\n}\n.ph-empty-record.is-pad {\n  padding: 1.76758rem 0 0.39063rem;\n}\n.ph-empty-record.is-pad .empty-image {\n  width: 2.02148rem;\n  margin: 0 auto 0.19531rem;\n}\n.ph-empty-record.is-pad .empty-text {\n  font-size: 0.23438rem;\n  line-height: 0.29297rem;\n}\n.ph-empty-record .empty-image {\n  width: 5.01333rem;\n  margin: 0 auto 0.26667rem;\n}\n.ph-empty-record .empty-text {\n  font-size: 0.42667rem;\n  line-height: 0.8rem;\n  color: #b5b7bd;\n}\n";
styleInject(css);

const PHONE_IMAGE = [
    {
        375: 'https://cdn.llscdn.com/phonics-ui/phone-empty.png',
        750: 'https://cdn.llscdn.com/phonics-ui/phone-empty@2x.png',
        1125: 'https://cdn.llscdn.com/phonics-ui/phone-empty@3x.png',
        height: `${168 / PHONE_RATIO}rem`
    }
];
const PAD_IMAGE = [
    {
        1024: 'https://cdn.llscdn.com/phonics-ui/pad-empty.png',
        2048: 'https://cdn.llscdn.com/phonics-ui/pad-empty@2x.png',
        3072: 'https://cdn.llscdn.com/phonics-ui/pad-empty@3x.png',
        height: `${207 / PAD_RATIO}rem`
    }
];
const DEFAULT_TEXT = '暂无数据';
function EmptyRecord(props) {
    const { isPad, className, text } = props;
    const emptyText = text || parseParams().text || DEFAULT_TEXT;
    return (React.createElement("div", { className: classnames('ph-empty-record', className, { 'is-pad': isPad }) },
        React.createElement(Imager, { className: "empty-image", isPad: isPad, imgList: isPad ? PAD_IMAGE : PHONE_IMAGE }),
        React.createElement("p", { className: "empty-text" }, emptyText)));
}

export default EmptyRecord;
