import classnames from 'classnames';
import { Component, createElement } from 'react';
import { LONG_TOUCH_DURATION, PAD_WIDTH_LIST, PHONE_WIDTH_LIST, MAX_MOVE } from '../common';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-imager div {\n  background-repeat: no-repeat;\n  background-size: contain;\n}\n.ph-imager .imager-container {\n  position: relative;\n}\n.ph-imager .imager-inner {\n  position: absolute;\n  left: 0;\n  right: 0;\n  top: 0;\n  bottom: 0;\n  max-width: 100%;\n}\n";
styleInject(css);

function getDPR() {
    let dpr = Math.floor(window.devicePixelRatio) || 1;
    if (dpr > 3)
        dpr = 3;
    if (dpr < 1)
        dpr = 1;
    return dpr;
}
class Imager extends Component {
    constructor() {
        super(...arguments);
        this.dpr = getDPR();
        this.container = null;
        this.touchTimer = null;
        this.touchX = 0;
        this.touchY = 0;
        this.onTouchStart = (e) => {
            const { pageX, pageY } = e.touches[0];
            this.touchX = pageX;
            this.touchY = pageY;
            this.touchTimer = Date.now();
        };
        this.onTouchEnd = (e) => {
            const touchDuration = Date.now() - this.touchTimer;
            const { pageX, pageY } = e.changedTouches[0];
            const { onLongTouch } = this.props;
            const { touchX, touchY } = this;
            const isMove = pageX - touchX > MAX_MOVE ||
                touchX - pageX > MAX_MOVE ||
                pageY - touchY > MAX_MOVE ||
                touchY - pageY > MAX_MOVE;
            if (touchDuration > LONG_TOUCH_DURATION && onLongTouch && !isMove) {
                onLongTouch();
            }
        };
    }
    componentDidMount() {
        this.initImage();
    }
    initImage() {
        const { imgList, onSuccess, onFailure } = this.props;
        let sequence = Promise.resolve();
        imgList.forEach((listItem, index) => {
            sequence = sequence.then(() => {
                return this.createImage(listItem, index);
            });
        });
        sequence.then(onSuccess, onFailure);
    }
    createImage(listItem, index) {
        const { dpr, props, container } = this;
        const { widthList, onClick, useDivInner, isPad } = props;
        const { height, divInner } = listItem;
        const isDivInner = typeof divInner === 'undefined' ? useDivInner : divInner;
        return new Promise((resolve, reject) => {
            const box = document.createElement('div');
            box.className = 'imager-container';
            if (height)
                box.style.height = height;
            if (container)
                container.appendChild(box);
            const nodeType = isDivInner ? 'div' : 'img';
            const imgEl = document.createElement(nodeType);
            imgEl.className = 'imager-inner';
            if (onClick) {
                imgEl.addEventListener('click', event => {
                    onClick(event, listItem, index);
                });
            }
            const list = widthList && widthList.length
                ? widthList
                : isPad
                    ? PAD_WIDTH_LIST
                    : PHONE_WIDTH_LIST;
            const resource = new Image();
            const miniImg = listItem[list[0]];
            const suitableImg = listItem[list[dpr - 1]];
            resource.onload = () => {
                box.style.backgroundImage = `url(${miniImg})`;
                box.style.backgroundSize = `100% 100%`;
                if (isDivInner) {
                    imgEl.style.backgroundImage = `url(${suitableImg})`;
                }
                else {
                    const el = imgEl;
                    el.src = suitableImg;
                    el.style.height = height;
                }
                box.appendChild(imgEl);
                resolve();
            };
            resource.onerror = err => {
                reject(err);
            };
            resource.src = miniImg;
        });
    }
    render() {
        const { className, isPad } = this.props;
        return (createElement("div", { onTouchStart: this.onTouchStart, onTouchEnd: this.onTouchEnd, onTouchCancel: this.onTouchEnd, ref: el => (this.container = el), className: classnames('ph-imager', className, { 'is-pad': isPad }) }));
    }
}
Imager.defaultProps = {
    className: '',
    onSuccess() { },
    onFailure() { }
};

export default Imager;
