import '@lls/lls-ui/es/Loading/style.css';
import classnames from 'classnames';
import { createElement } from 'react';
import ReactDOM from 'react-dom';
import Loading from '@lls/lls-ui/es/Loading';
import { getIsPadDisplay } from '../utils';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-loading {\n  position: fixed;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  z-index: 1000;\n  background: rgba(181, 183, 188, 0.2);\n}\n.ph-loading.is-pad .loading-wrapper {\n  width: 1.95313rem;\n  padding: 0.19531rem 0.09766rem;\n  border-radius: 0.07813rem;\n}\n.ph-loading.is-pad .loading-wrapper .lls-ui-loading__gd {\n  width: 0.35156rem;\n  height: 0.35156rem;\n  border-width: 0.04883rem;\n}\n.ph-loading.is-pad .loading-wrapper .loading-text {\n  margin-top: 0.14648rem;\n  font-size: 0.17578rem;\n}\n.ph-loading.info-loading .loading-wrapper {\n  background-color: #fff;\n}\n.ph-loading .loading-wrapper {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  width: 5.33333rem;\n  padding: 0.53333rem 0.26667rem;\n  text-align: center;\n  border-radius: 0.21333rem;\n  -webkit-transform: translate(-50%, -50%);\n          transform: translate(-50%, -50%);\n}\n.ph-loading .loading-wrapper .lls-ui-loading__gd {\n  margin: 0 auto;\n}\n.ph-loading .loading-wrapper .loading-text {\n  margin-top: 0.4rem;\n  margin-bottom: 0;\n  word-break: break-all;\n}\n";
styleInject(css);

const LoadingComponent = (props) => {
    const { force, isPad, text } = props;
    return (createElement("div", { className: classnames('ph-loading', {
            'is-pad': isPad,
            'info-loading': text
        }) },
        createElement("div", { className: "loading-wrapper" },
            createElement(Loading, { force: force }),
            text && createElement("p", { className: "loading-text" }, text))));
};
var index = new class Loading {
    constructor() {
        this.loadingEl = null;
        this.counter = 0;
    }
    clear() {
        const { loadingEl } = this;
        if (loadingEl) {
            this.loadingEl = null;
            document.body.removeChild(loadingEl);
            this.counter = 0;
        }
    }
    show(text, force) {
        const isPad = getIsPadDisplay();
        if (this.counter <= 0) {
            this.loadingEl = this.addNode(createElement(LoadingComponent, { isPad: isPad, force: force, text: text }));
        }
        this.counter++;
    }
    hide() {
        const { loadingEl, counter } = this;
        if (loadingEl && counter <= 1) {
            document.body.removeChild(loadingEl);
            this.loadingEl = null;
        }
        if (counter > 0)
            this.counter--;
    }
    addNode(element) {
        const div = document.createElement('div');
        document.body.appendChild(div);
        ReactDOM.render(element, div);
        return div;
    }
}();

export default index;
