import classnames from 'classnames';
import React from 'react';
import ReactDOM from 'react-dom';
import { PHONE_RATIO, PAD_RATIO } from '../common';
import Imager from '../imager';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-page-loading {\n  position: fixed;\n  left: 0;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  z-index: 200;\n  background-color: #fff;\n  text-align: center;\n}\n.ph-page-loading.is-pad .loading-image {\n  width: 0.91797rem;\n  margin: 2.39258rem auto 0;\n}\n.ph-page-loading.is-pad .loading-text {\n  margin-top: 0.23438rem;\n  font-size: 0.23438rem;\n  line-height: 0.29297rem;\n}\n.ph-page-loading .loading-image {\n  width: 2.29333rem;\n  margin: 4.98667rem auto 0;\n  -webkit-animation: 1.5s loading-plane infinite;\n          animation: 1.5s loading-plane infinite;\n}\n.ph-page-loading .loading-text {\n  margin-top: 0.45333rem;\n  font-size: 0.42667rem;\n  line-height: 0.8rem;\n  color: #b5b7bd;\n  position: relative;\n  display: inline-block;\n}\n.ph-page-loading .loading-text::after {\n  content: '·';\n  position: absolute;\n  left: 100%;\n  text-align: left;\n  -webkit-animation: 2s loading-text infinite;\n          animation: 2s loading-text infinite;\n}\n@-webkit-keyframes loading-plane {\n  0% {\n    -webkit-transform: translateY(0);\n            transform: translateY(0);\n  }\n  50% {\n    -webkit-transform: translateY(-0.21333rem);\n            transform: translateY(-0.21333rem);\n  }\n  100% {\n    -webkit-transform: translateY(0);\n            transform: translateY(0);\n  }\n}\n@keyframes loading-plane {\n  0% {\n    -webkit-transform: translateY(0);\n            transform: translateY(0);\n  }\n  50% {\n    -webkit-transform: translateY(-0.21333rem);\n            transform: translateY(-0.21333rem);\n  }\n  100% {\n    -webkit-transform: translateY(0);\n            transform: translateY(0);\n  }\n}\n@-webkit-keyframes loading-text {\n  0% {\n    content: '';\n  }\n  30% {\n    content: '·';\n  }\n  60% {\n    content: '··';\n  }\n  100% {\n    content: '···';\n  }\n}\n@keyframes loading-text {\n  0% {\n    content: '';\n  }\n  30% {\n    content: '·';\n  }\n  60% {\n    content: '··';\n  }\n  100% {\n    content: '···';\n  }\n}\n";
styleInject(css);

const PHONE_IMAGE = [
    {
        375: 'https://cdn.llscdn.com/sprout/assets/invalidName_phone.png',
        750: 'https://cdn.llscdn.com/sprout/assets/invalidName_phone@2x.png',
        1125: 'https://cdn.llscdn.com/sprout/assets/invalidName_phone@3x.png',
        height: `${62 / PHONE_RATIO}rem`
    }
];
const PAD_IMAGE = [
    {
        1024: 'https://cdn.llscdn.com/sprout/assets/invalidName_pad.png',
        2048: 'https://cdn.llscdn.com/sprout/assets/invalidName_pad@2x.png',
        3072: 'https://cdn.llscdn.com/sprout/assets/invalidName_pad@3x.png',
        height: `${68 / PAD_RATIO}rem`
    }
];
function PageLoading(props) {
    const { isPad = false, className = '' } = props || {};
    return (React.createElement("div", { className: classnames('ph-page-loading', className, { 'is-pad': isPad }) },
        React.createElement(Imager, { className: "loading-image", isPad: isPad, imgList: isPad ? PAD_IMAGE : PHONE_IMAGE }),
        React.createElement("div", { className: "loading-text" }, "\u52AA\u529B\u52A0\u8F7D\u4E2D")));
}
function index (props) {
    let loadingEl;
    return {
        show() {
            const div = document.createElement('div');
            document.body.appendChild(div);
            ReactDOM.render(React.createElement(PageLoading, Object.assign({}, props)), div);
            loadingEl = div;
        },
        hide() {
            if (loadingEl)
                document.body.removeChild(loadingEl);
            loadingEl = null;
        }
    };
}

export default index;
export { PageLoading };
