import React, { Component } from 'react';
import bard from '@lls/bard';
import UserAgent from '@lls/client-js/es/UserAgent';
import PageFail from '../page-fail';
import PageLoading from '../page-loading';
import parseParams from '../parse-params';
import { isObject, isFunction, getIsPadDisplay, loadPrimaryFont, preloadImage, toArray } from '../utils';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = "@font-face {\n  font-family: \"FZY4JW\";\n  font-style: normal;\n  font-weight: normal;\n  src: url(\"https://cdn.llscdn.com/FZY4JW.TTF\") format(\"truetype\");\n}\n.font-primary {\n  font-family: \"FZY4JW\" !important;\n}\n";
styleInject(css);

function setGangFour({ deviceId, sDeviceId, token, appId, userLogin }) {
    localStorage.setItem('TOKEN', JSON.stringify(token));
    localStorage.setItem('APP_ID', JSON.stringify(appId));
    localStorage.setItem('DEVICE_ID', JSON.stringify(deviceId));
    localStorage.setItem('S_DEVICE_ID', JSON.stringify(sDeviceId));
    localStorage.setItem('USER_LOGIN', JSON.stringify(userLogin));
}
function getVisibilityName() {
    let hidden = '';
    let visibilityChange = '';
    if (typeof document.hidden !== 'undefined') {
        hidden = 'hidden';
        visibilityChange = 'visibilitychange';
    }
    else if (typeof document.msHidden !== 'undefined') {
        hidden = 'msHidden';
        visibilityChange = 'msvisibilitychange';
    }
    else if (typeof document.webkitHidden !== 'undefined') {
        hidden = 'webkitHidden';
        visibilityChange = 'webkitvisibilitychange';
    }
    return { hidden, visibilityChange };
}
const { hidden, visibilityChange } = getVisibilityName();
function PageWrapper(target) {
    // TODO: fix type
    let usePrimaryFont = false;
    let notJudgePad = false;
    let useAuthInApp = false;
    let preloadSync = false;
    let preload = [];
    function getAppAuth() {
        const { deviceId, sDeviceId, token, appId } = parseParams();
        if (deviceId && sDeviceId && token && appId) {
            const result = { deviceId, sDeviceId, token, appId, userLogin: '' };
            setGangFour(result);
            return Promise.resolve(result);
        }
        else if (UserAgent.isHybrid) {
            return bard
                .invoke('getAuthData')
                .then(({ deviceId, sDeviceId, token, appId, userLogin }) => {
                const result = { deviceId, sDeviceId, token, appId, userLogin };
                setGangFour(result);
                return result;
            });
        }
        else {
            return Promise.resolve();
        }
    }
    const pageHoc = (OriginComponent) => {
        const hasFetch = isFunction(OriginComponent.fetch);
        class PhPageWrapper extends Component {
            constructor() {
                super(...arguments);
                this.state = {
                    loading: hasFetch || useAuthInApp || !!preload.length,
                    auth: null,
                    data: null,
                    error: null
                };
                this.isPad = getIsPadDisplay();
                this.onOrientationChange = () => {
                    window.location.reload();
                };
            }
            componentWillMount() {
                if (usePrimaryFont)
                    loadPrimaryFont();
                const { loading: showLoading } = this.state;
                if (!showLoading)
                    return;
                const { isPad } = this;
                const loading = PageLoading({ isPad });
                loading.show();
                let auth = null;
                let data = null;
                const authPromise = useAuthInApp ? getAppAuth() : Promise.resolve(null);
                let loadImage = preloadImage(preload).catch(_ => _);
                let imgPromise = preloadSync ? loadImage : Promise.resolve(null);
                Promise.all([authPromise, imgPromise])
                    .then(([res]) => {
                    if (res)
                        auth = res;
                    if (hasFetch) {
                        return OriginComponent.fetch({ ...this.props, auth: res }).then((d) => (data = d));
                    }
                })
                    .then(() => {
                    this.setState({ data, auth, loading: false });
                    loading.hide();
                })
                    .catch((err) => {
                    this.setState({ error: err || true, loading: false });
                    loading.hide();
                });
            }
            handleVChange() {
                const videos = toArray(document.querySelectorAll('video'));
                const audios = toArray(document.querySelectorAll('audio'));
                if (document[hidden]) {
                    videos.forEach(video => {
                        video.pause();
                    });
                    audios.forEach(audio => {
                        audio.pause();
                    });
                }
            }
            componentDidMount() {
                document.addEventListener(visibilityChange, this.handleVChange);
                if (!notJudgePad) {
                    if (this.isPad)
                        document.body.classList.add('ph-pad-body');
                    window.addEventListener('orientationchange', this.onOrientationChange);
                }
            }
            componentWillUnmount() {
                document.addEventListener(visibilityChange, this.handleVChange);
                if (!notJudgePad) {
                    window.removeEventListener('orientationchange', this.onOrientationChange);
                }
            }
            render() {
                const { loading, data, error, auth } = this.state;
                const { jest } = this.props;
                if (jest) {
                    const { jest, ...props } = this.props;
                    return React.createElement(OriginComponent, Object.assign({}, props));
                }
                if (loading)
                    return null;
                if (error)
                    return React.createElement(PageFail, { isPad: this.isPad });
                const props = { data, ...this.props, auth };
                if (!notJudgePad)
                    props.isPad = this.isPad;
                return React.createElement(OriginComponent, Object.assign({}, props));
            }
        }
        return PhPageWrapper;
    };
    if (target && target.prototype instanceof Component) {
        return pageHoc(target);
    }
    else {
        if (isObject(target)) {
            usePrimaryFont = !!target.usePrimaryFont;
            notJudgePad = !!target.notJudgePad;
            useAuthInApp = !!target.useAuthInApp;
            preload = target.preload || [];
            preloadSync = target.preloadSync;
        }
        return pageHoc;
    }
}

export default PageWrapper;
