import classnames from 'classnames';
import React, { PureComponent } from 'react';
import { PAD_RATIO, PHONE_RATIO } from '../common';
import { loadImage } from '../utils';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-picture {\n  display: block;\n}\n.ph-picture div {\n  background-repeat: no-repeat;\n  background-size: contain;\n}\n.ph-picture .imager-container {\n  position: relative;\n  background-size: 100% 100%;\n}\n.ph-picture .imager-inner {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  max-width: 100%;\n}\n";
styleInject(css);

function getDPR() {
    let dpr = Math.floor(window.devicePixelRatio) || 1;
    if (dpr > 3)
        dpr = 3;
    if (dpr < 1)
        dpr = 1;
    return dpr;
}
class Picture extends PureComponent {
    constructor() {
        super(...arguments);
        this.container = null;
        this.dpr = getDPR();
    }
    componentDidMount() {
        this.initImage();
    }
    componentWillUnmount() {
        this.container = null;
    }
    initImage() {
        const { img, list, onSuccess, onFailure } = this.props;
        const imgList = img ? [img] : list;
        let sequence = Promise.resolve();
        imgList.forEach((listItem, index) => {
            sequence = sequence.then(() => {
                return this.createImage(listItem, index);
            });
        });
        sequence.then(onSuccess, onFailure);
    }
    createImage(listItem, index) {
        const { dpr, props, container } = this;
        const { onClick, useDivInner, pxToRem, isPad, width: superWidth, replace } = props;
        const { width: itemWidth, height, divInner, src } = listItem;
        const isDivInner = typeof divInner === 'undefined' ? useDivInner : divInner;
        const ratio = isPad ? PAD_RATIO : PHONE_RATIO;
        const heightString = pxToRem ? `${height / ratio}rem` : `${height}px`;
        const width = itemWidth || superWidth;
        const widthString = width && pxToRem ? `${width / ratio}rem` : `${width}px`;
        return new Promise((resolve, reject) => {
            if (!container)
                return;
            const box = document.createElement('div');
            box.className = 'imager-container';
            box.style.height = heightString;
            if (widthString)
                box.style.width = widthString;
            container.appendChild(box);
            if (onClick) {
                box.addEventListener('click', event => {
                    onClick(event, listItem, index);
                });
            }
            const nodeType = isDivInner ? 'div' : 'img';
            const imgEl = document.createElement(nodeType);
            imgEl.className = 'imager-inner';
            const resource = new Image();
            const miniImg = `${src}?imageView2/2/h/${height}`;
            const suitableImg = dpr === 3 ? src : `${src}?imageView2/2/h/${height * dpr}`;
            resource.onload = () => {
                box.style.backgroundImage = `url(${miniImg})`;
                const suitableImgLoader = replace
                    ? loadImage(suitableImg)
                    : Promise.resolve({});
                suitableImgLoader.then(() => {
                    if (isDivInner) {
                        imgEl.style.backgroundImage = `url(${suitableImg})`;
                    }
                    else {
                        const el = imgEl;
                        el.src = suitableImg;
                        el.style.height = heightString;
                        if (widthString)
                            el.style.width = widthString;
                    }
                    if (box)
                        box.appendChild(imgEl);
                    if (replace)
                        box.style.backgroundImage = '';
                });
                resolve();
            };
            resource.onerror = err => {
                reject(err);
            };
            resource.src = miniImg;
        });
    }
    render() {
        const { className, isPad } = this.props;
        return (React.createElement("div", { ref: el => (this.container = el), className: classnames('ph-picture', className, { 'is-pad': isPad }) }));
    }
}
Picture.defaultProps = {
    pxToRem: true
};

export default Picture;
