import classnames from 'classnames';
import React, { PureComponent } from 'react';
import ReactDOM from 'react-dom';
import { getIsPadDisplay } from '../utils';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-share-notice {\n  position: fixed;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  background: rgba(0, 0, 0, 0.6);\n  z-index: 9999;\n}\n.ph-share-notice .ph-share-mark-img {\n  position: absolute;\n  width: 1.62667rem;\n  height: 4.72rem;\n  top: 0;\n  right: 0;\n  background: url(https://cdn.llscdn.com/sprout/sprout-hybrid/wechat/wechat-mark.png) no-repeat;\n  background-size: contain;\n  touch-action: none;\n}\n.ph-share-notice .ph-share-mark-img.is-ipad {\n  -webkit-transform: scale(0.3955);\n          transform: scale(0.3955);\n  -webkit-transform-origin: top right;\n          transform-origin: top right;\n}\n.ph-share-notice .ph-share-mark-texts {\n  position: absolute;\n  top: 2.66667rem;\n  right: 1.33333rem;\n}\n.ph-share-notice .ph-share-mark-texts.is-ipad {\n  -webkit-transform: scale(0.3955);\n          transform: scale(0.3955);\n  -webkit-transform-origin: top right;\n          transform-origin: top right;\n  top: 1.33333rem;\n  right: 0.53333rem;\n}\n.ph-share-notice p {\n  color: #fff;\n  font-size: 0.42667rem;\n  line-height: 1.5;\n}\n";
styleInject(css);

const noop = () => { };
class ShareNoticeComponent extends PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            show: null
        };
    }
    componentWillUpdate(_, state) {
        if (this.state.show !== false && state.show === false) {
            if (typeof this.props.onHide === 'function') {
                this.props.onHide();
            }
        }
    }
    render() {
        const { isPad, show: propShow } = this.props;
        if (!propShow)
            return '';
        const stateShow = this.state.show;
        const show = typeof stateShow === 'object' && !stateShow ? true : stateShow;
        return show ? (React.createElement("div", { className: "ph-share-notice", onClick: this.onClick.bind(this) },
            "'is-ipad': isPad",
            React.createElement("div", { className: classnames('ph-share-mark-img', {}) }),
            React.createElement("div", { className: classnames('ph-share-mark-texts', {
                    'is-ipad': isPad
                }) },
                React.createElement("p", null, "\u70B9\u51FB\u53F3\u4E0A\u89D2\u56FE\u6807\uFF0C"),
                React.createElement("p", null, "\u9009\u62E9\u5206\u4EAB\u5230\u670B\u53CB\u5708")))) : ('');
    }
    onClick() {
        this.setState({
            show: false
        });
    }
}
class ShareNotice {
    constructor(onHide = noop) {
        this.shareEl = null;
        this.propShow = true;
        this.onHide = onHide;
    }
    static show() {
        new ShareNotice().show();
    }
    show() {
        this.propShow = true;
        const isPad = getIsPadDisplay();
        if (!this.shareEl) {
            this.shareEl = this.addNode(React.createElement(ShareNoticeComponent, { isPad: isPad, show: this.propShow, onHide: this.removeNode.bind(this) }));
        }
    }
    hide() {
        if (!this.shareEl)
            return;
        this.propShow = false;
        if (typeof this.onHide === 'function') {
            this.onHide();
        }
        this.removeNode(false);
    }
    removeNode(callOnHide = true) {
        if (!this.shareEl)
            return;
        if (callOnHide) {
            this.onHide();
        }
        // tslint:disable-next-line: no-non-null-assertion
        this.shareEl.parentNode.removeChild(this.shareEl);
        this.shareEl = null;
    }
    addNode(element) {
        const div = document.createElement('div');
        document.body.appendChild(div);
        ReactDOM.render(element, div);
        return div;
    }
}

export default ShareNotice;
