import classnames from 'classnames';
import React, { PureComponent } from 'react';
import Avatar from '../avatar/index';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".ph-subtitle {\n  display: -webkit-box;\n  display: flex;\n  font-size: 0.32rem;\n  border-radius: 266.66667rem;\n}\n.ph-subtitle.is-pad {\n  font-size: 0.11719rem;\n}\n.ph-subtitle.is-pad .main-container {\n  height: 0.39063rem;\n  margin-left: 0.05859rem;\n}\n.ph-subtitle.is-pad .main-container .scroll-box {\n  margin-right: 0.09766rem;\n}\n.ph-subtitle.is-pad .main-container .scroll-box.transiting {\n  -webkit-transform: translateY(-0.39063rem);\n          transform: translateY(-0.39063rem);\n}\n.ph-subtitle.is-pad .main-container .scroll-box .subtitle-column {\n  height: 0.39063rem;\n  line-height: 0.39063rem;\n}\n.ph-subtitle.is-pad .main-container .scroll-box .subtitle-column .ph-avatar {\n  width: 0.29297rem;\n  height: 0.29297rem;\n  margin-top: 0.04883rem;\n  margin-right: 0.09766rem;\n}\n.ph-subtitle.is-pad .right-container {\n  margin-right: 0.19531rem;\n  line-height: 0.39063rem;\n}\n.ph-subtitle .main-container {\n  -webkit-box-flex: 1;\n          flex: 1;\n  overflow: hidden;\n  height: 1.06667rem;\n  margin-left: 0.16rem;\n}\n.ph-subtitle .main-container .scroll-box {\n  margin-right: 0.26667rem;\n  -webkit-transform: translateY(0);\n          transform: translateY(0);\n  will-change: transform;\n}\n.ph-subtitle .main-container .scroll-box.transiting {\n  -webkit-transform: translateY(-1.06667rem);\n          transform: translateY(-1.06667rem);\n  -webkit-transition: -webkit-transform 1s;\n  transition: -webkit-transform 1s;\n  transition: transform 1s;\n  transition: transform 1s, -webkit-transform 1s;\n}\n.ph-subtitle .main-container .scroll-box .subtitle-column {\n  display: -webkit-inline-box;\n  display: inline-flex;\n  max-width: 100%;\n  height: 1.06667rem;\n  color: #fff;\n  line-height: 1.06667rem;\n}\n.ph-subtitle .main-container .scroll-box .subtitle-column .ph-avatar {\n  width: 0.8rem;\n  height: 0.8rem;\n  margin-top: 0.13333rem;\n  margin-right: 0.26667rem;\n}\n.ph-subtitle .main-container .scroll-box .subtitle-column .subtitle-name {\n  -webkit-box-flex: 1;\n          flex: 1;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n}\n.ph-subtitle .main-container .scroll-box .subtitle-column .subtitle-text {\n  display: inline-block;\n}\n.ph-subtitle .right-container {\n  display: inline-block;\n  margin-right: 0.53333rem;\n  line-height: 1.06667rem;\n}\n.ph-subtitle .right-container .right-num {\n  color: #ffbb0b;\n}\n.ph-subtitle .right-container .right-text {\n  color: #fff;\n}\n";
styleInject(css);

class Subtitle extends PureComponent {
    constructor() {
        super(...arguments);
        this.state = { transiting: false, currentIndex: 0 };
        this.timeoutToken = null;
        this.intervalToekn = null;
        this.el = null;
        this.visible = true;
        this.terminateCurrentTransition = () => {
            this.setState({ transiting: false, currentIndex: this.getNextIndex() });
            this.scheduleNextTransition();
        };
    }
    scheduleNextTransition() {
        this.timeoutToken = setTimeout(() => {
            this.setState({ transiting: true });
        }, this.props.duration);
    }
    componentDidMount() {
        if (this.props.watchVisible) {
            this.intervalToekn = setInterval(() => {
                const { width } = this.el.getBoundingClientRect();
                if (width && !this.visible) {
                    this.visible = true;
                    this.terminateCurrentTransition();
                }
                if (!width && this.visible) {
                    this.visible = false;
                }
            }, this.props.watchCheckDuration);
        }
        this.scheduleNextTransition();
    }
    getNextIndex() {
        const { currentIndex: index } = this.state;
        const nextIndex = index + 1;
        return nextIndex === this.props.textList.length ? 0 : nextIndex;
    }
    componentWillUnmount() {
        if (this.timeoutToken)
            clearTimeout(this.timeoutToken);
        if (this.props.watchVisible)
            clearInterval(this.intervalToekn);
    }
    render() {
        const { rightText, background, textList, isPad, className } = this.props;
        const { transiting, currentIndex } = this.state;
        const { num, text } = rightText;
        const list = textList.slice(currentIndex, currentIndex + 2);
        if (list.length === 1)
            list.push(textList[0]);
        return (React.createElement("div", { className: classnames('ph-subtitle', className, { 'is-pad': isPad }), ref: el => (this.el = el), style: { background } },
            React.createElement("div", { className: "main-container" },
                React.createElement("div", { className: classnames('scroll-box', { transiting }), onTransitionEnd: this.terminateCurrentTransition }, list.map(({ name, text, gender }, index) => (React.createElement("div", { key: index },
                    React.createElement("div", { className: "subtitle-column" },
                        React.createElement(Avatar, { gender: gender }),
                        React.createElement("div", { className: "subtitle-name" }, name),
                        React.createElement("div", { className: "subtitle-text" }, text))))))),
            React.createElement("div", { className: "right-container" },
                React.createElement("span", { className: "right-num" }, num),
                React.createElement("span", { className: "right-text" }, text))));
    }
}
Subtitle.defaultProps = {
    background: '#9468D9',
    duration: 1000,
    watchCheckDuration: 100
};

export default Subtitle;
