import FontFaceObserver from 'fontfaceobserver';

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectSpread(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};
    var ownKeys = Object.keys(source);

    if (typeof Object.getOwnPropertySymbols === 'function') {
      ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) {
        return Object.getOwnPropertyDescriptor(source, sym).enumerable;
      }));
    }

    ownKeys.forEach(function (key) {
      _defineProperty(target, key, source[key]);
    });
  }

  return target;
}

var CanvasSubTypes;

(function (CanvasSubTypes) {
  CanvasSubTypes["Text"] = "text";
  CanvasSubTypes["Image"] = "image";
})(CanvasSubTypes || (CanvasSubTypes = {}));

var Canvas =
/*#__PURE__*/
function () {
  function Canvas(settings, options, element) {
    var _this = this;

    _classCallCheck(this, Canvas);

    this.imageList = {};
    this.ratio = 1;
    var width = settings.width,
        height = settings.height,
        bgColor = settings.bgColor,
        bgImage = settings.bgImage,
        usePrimaryFont = settings.usePrimaryFont,
        ratio = settings.ratio;
    if (ratio) this.ratio = ratio;
    this.canvas = element || document.createElement('canvas');
    this.canvas.width = width * this.ratio;
    this.canvas.height = height * this.ratio;
    this.canvas.setAttribute('style', '-moz-osx-font-smoothing: grayscale;-webkit-font-smoothing: antialiased;display:none');
    document.body.appendChild(this.canvas);
    this.ctx = this.canvas.getContext('2d', {
      alpha: false
    });
    this.settings = settings;
    this.options = options;

    if (bgColor) {
      this.drawRect(0, 0, width, height, {
        fillStyle: bgColor
      });
    }

    this.imageLoader = Promise.resolve();
    this.collectImage();
    var fontLoader = Promise.resolve();

    if (usePrimaryFont) {
      this.canvas.style.fontFamily = 'FZY4JW';
      var FONT_LOAD_MAX_TIME = 30000;
      var FONT_NAME = 'FZY4JW';
      var font = new FontFaceObserver(FONT_NAME);
      fontLoader = font.load(null, FONT_LOAD_MAX_TIME);
    }

    this.loader = Promise.all([this.imageLoader, fontLoader]);
    this.loader.then(function () {
      if (bgImage) {
        _this.drawImage({
          type: CanvasSubTypes.Image,
          src: bgImage,
          position: {
            x: 0,
            y: 0,
            width: width,
            height: height
          }
        });
      }

      _this.initOptions();
    });
  }

  _createClass(Canvas, [{
    key: "getExtra",
    value: function getExtra(extra) {
      var result = _objectSpread({}, extra);

      if (result.font) {
        var fontSize = result.font.match(/\d+px/);
        fontSize = parseInt(fontSize, 10) * this.ratio;
        result.font = result.font.replace(/\d+px/, "".concat(fontSize, "px"));
      }

      return result;
    }
  }, {
    key: "initOptions",
    value: function initOptions() {
      var _this2 = this;

      this.options.forEach(function (option) {
        _this2.ctx.beginPath();

        _extends(_this2.ctx, _this2.getExtra(option.extra));

        switch (option.type) {
          case CanvasSubTypes.Text:
            _this2.createText(option);

            break;

          case CanvasSubTypes.Image:
            _this2.drawImage(option);

            break;
        }
      });
    }
  }, {
    key: "createText",
    value: function createText(item) {
      var _this3 = this;

      var position = item.position,
          text = item.text,
          maxWidth = item.maxWidth,
          lineHeight = item.lineHeight,
          styled = item.styled,
          extra = item.extra,
          del = item.del;
      var isDelete = Boolean(del);
      var x = position.x,
          y = position.y;
      this.ctx.lineWidth = 1;

      if (maxWidth && lineHeight) {
        var textArr = text.split('');
        var line = '';
        textArr.forEach(function (word, index) {
          var testLine = line + word;

          var metrics = _this3.ctx.measureText(testLine);

          var testWidth = metrics.width;

          if (testWidth > maxWidth * _this3.ratio && index) {
            _this3.drawText(line, x, y, isDelete);

            line = word;
            y += lineHeight;
          } else {
            line = testLine;
          }
        });
        this.drawText(line, x, y, isDelete);
      } else if (styled) {
        var _textArr = text.split('');

        var _line = '';

        _textArr.forEach(function (word) {
          if (word === '<') {
            _this3.drawText(_line, x, y, isDelete);

            x += _this3.ctx.measureText(_line).width / _this3.ratio;

            _extends(_this3.ctx, styled);

            _line = '';
          } else if (word === '>') {
            _this3.drawText(_line, x, y, isDelete);

            x += _this3.ctx.measureText(_line).width / _this3.ratio;

            _extends(_this3.ctx, _this3.getExtra(extra));

            _line = '';
          } else {
            _line += word;
          }
        });

        this.drawText(_line, x, y, isDelete);
      } else {
        this.drawText(text, x, y, isDelete);
      }
    }
  }, {
    key: "collectImage",
    value: function collectImage() {
      var _this4 = this;

      var settings = this.settings,
          options = this.options;
      var bgImage = settings.bgImage;
      if (bgImage) this.imageList[bgImage] = null;
      options.forEach(function (option) {
        if (option.type === CanvasSubTypes.Image) {
          _this4.imageList[option.src] = null;
        }
      });
      this.imageLoader = Promise.all(Object.keys(this.imageList).map(function (imgSrc) {
        return new Promise(function (resolve, reject) {
          var image = new Image();

          if (!/^data:(.*);base64,/.test(imgSrc)) {
            image.setAttribute('crossOrigin', 'anonymous');
          }

          image.onload = function () {
            _this4.imageList[imgSrc] = image;
            resolve(image);
          };

          image.onerror = function () {
            reject(image);
          };

          image.src = imgSrc;
        });
      }));
    }
  }, {
    key: "drawImage",
    value: function drawImage(item) {
      var src = item.src,
          position = item.position;
      var x = position.x,
          y = position.y,
          _position$width = position.width,
          width = _position$width === void 0 ? this.imageList[src].width : _position$width,
          _position$height = position.height,
          height = _position$height === void 0 ? this.imageList[src].height : _position$height;
      this.ctx.drawImage(this.imageList[src], x * this.ratio, y * this.ratio, width * this.ratio, height * this.ratio);
    }
  }, {
    key: "drawText",
    value: function drawText(text, x, y, del) {
      this.ctx.fillText(text, x * this.ratio, y * this.ratio);

      if (del) {
        var _this$ctx$measureText = this.ctx.measureText(text),
            width = _this$ctx$measureText.width;

        var fontSizeMath = this.ctx.font.match(/\d+/);
        var fontSize = parseFloat(fontSizeMath && fontSizeMath[0] || '0');
        var verticalPos = this.ratio * y - fontSize / 2 + 1;
        this.ctx.moveTo(x * this.ratio, verticalPos);
        this.ctx.lineWidth = 2 * this.ratio;
        var fillStyle = this.ctx.fillStyle;
        this.ctx.strokeStyle = fillStyle;
        this.ctx.lineTo(this.ratio * x + width, verticalPos);
        this.ctx.stroke();
      }
    }
  }, {
    key: "drawRect",
    value: function drawRect(x, y, width, height, options) {
      var fillStyle = options.fillStyle,
          strokeStyle = options.strokeStyle;
      this.ctx.beginPath();
      this.ctx.rect(x * this.ratio, y * this.ratio, width * this.ratio, height * this.ratio);

      if (fillStyle) {
        this.ctx.fillStyle = fillStyle;
        this.ctx.fill();
      }

      if (strokeStyle) {
        this.ctx.strokeStyle = strokeStyle;
        this.ctx.stroke();
      }
    }
  }, {
    key: "getBase64Data",
    value: function getBase64Data() {
      var _this5 = this;

      return this.loader.then(function () {
        return _this5.canvas.toDataURL('image/png', 1.0);
      });
    }
  }]);

  return Canvas;
}();
/** 获取图片base64信息 */


function getImage(settings, options, element) {
  var image = new Canvas(settings, options, element);
  return image.getBase64Data();
}

export default getImage;
export { CanvasSubTypes };
