import classnames from 'classnames';
import React__default, { createElement, Component } from 'react';
import ReactDOM from 'react-dom';

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

// tslint:disable-next-line
var PHONE_WIDTH_LIST = [375, 750, 1125]; // tslint:disable-next-line

var PAD_WIDTH_LIST = [1024, 2048, 3072];
var PHONE_RATIO = 37.5;
var PAD_RATIO = 102.4;
var LONG_TOUCH_DURATION = 700;
var MAX_MOVE = 5;

function getDPR() {
  var dpr = Math.floor(window.devicePixelRatio) || 1;
  if (dpr > 3) dpr = 3;
  if (dpr < 1) dpr = 1;
  return dpr;
}

var Imager =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Imager, _React$Component);

  function Imager() {
    var _this;

    _classCallCheck(this, Imager);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Imager).apply(this, arguments));
    _this.dpr = getDPR();
    _this.container = null;
    _this.touchTimer = null;
    _this.touchX = 0;
    _this.touchY = 0;

    _this.onTouchStart = function (e) {
      var _e$touches$ = e.touches[0],
          pageX = _e$touches$.pageX,
          pageY = _e$touches$.pageY;
      _this.touchX = pageX;
      _this.touchY = pageY;
      _this.touchTimer = Date.now();
    };

    _this.onTouchEnd = function (e) {
      var touchDuration = Date.now() - _this.touchTimer;

      var _e$changedTouches$ = e.changedTouches[0],
          pageX = _e$changedTouches$.pageX,
          pageY = _e$changedTouches$.pageY;
      var onLongTouch = _this.props.onLongTouch;

      var _assertThisInitialize = _assertThisInitialized(_this),
          touchX = _assertThisInitialize.touchX,
          touchY = _assertThisInitialize.touchY;

      var isMove = pageX - touchX > MAX_MOVE || touchX - pageX > MAX_MOVE || pageY - touchY > MAX_MOVE || touchY - pageY > MAX_MOVE;

      if (touchDuration > LONG_TOUCH_DURATION && onLongTouch && !isMove) {
        onLongTouch();
      }
    };

    return _this;
  }

  _createClass(Imager, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.initImage();
    }
  }, {
    key: "initImage",
    value: function initImage() {
      var _this2 = this;

      var _this$props = this.props,
          imgList = _this$props.imgList,
          onSuccess = _this$props.onSuccess,
          onFailure = _this$props.onFailure;
      var sequence = Promise.resolve();
      imgList.forEach(function (listItem, index) {
        sequence = sequence.then(function () {
          return _this2.createImage(listItem, index);
        });
      });
      sequence.then(onSuccess, onFailure);
    }
  }, {
    key: "createImage",
    value: function createImage(listItem, index) {
      var dpr = this.dpr,
          props = this.props,
          container = this.container;
      var widthList = props.widthList,
          onClick = props.onClick,
          useDivInner = props.useDivInner,
          isPad = props.isPad;
      var height = listItem.height,
          divInner = listItem.divInner;
      var isDivInner = typeof divInner === 'undefined' ? useDivInner : divInner;
      return new Promise(function (resolve, reject) {
        var box = document.createElement('div');
        box.className = 'imager-container';
        if (height) box.style.height = height;
        if (container) container.appendChild(box);
        var nodeType = isDivInner ? 'div' : 'img';
        var imgEl = document.createElement(nodeType);
        imgEl.className = 'imager-inner';

        if (onClick) {
          imgEl.addEventListener('click', function (event) {
            onClick(event, listItem, index);
          });
        }

        var list = widthList && widthList.length ? widthList : isPad ? PAD_WIDTH_LIST : PHONE_WIDTH_LIST;
        var resource = new Image();
        var miniImg = listItem[list[0]];
        var suitableImg = listItem[list[dpr - 1]];

        resource.onload = function () {
          box.style.backgroundImage = "url(".concat(miniImg, ")");
          box.style.backgroundSize = "100% 100%";

          if (isDivInner) {
            imgEl.style.backgroundImage = "url(".concat(suitableImg, ")");
          } else {
            var el = imgEl;
            el.src = suitableImg;
            el.style.height = height;
          }

          box.appendChild(imgEl);
          resolve();
        };

        resource.onerror = function (err) {
          reject(err);
        };

        resource.src = miniImg;
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var _this$props2 = this.props,
          className = _this$props2.className,
          isPad = _this$props2.isPad;
      return createElement("div", {
        onTouchStart: this.onTouchStart,
        onTouchEnd: this.onTouchEnd,
        onTouchCancel: this.onTouchEnd,
        ref: function ref(el) {
          return _this3.container = el;
        },
        className: classnames('ph-imager', className, {
          'is-pad': isPad
        })
      });
    }
  }]);

  return Imager;
}(Component);
Imager.defaultProps = {
  className: '',
  onSuccess: function onSuccess() {},
  onFailure: function onFailure() {}
};

var PHONE_IMAGE = [{
  375: 'https://cdn.llscdn.com/sprout/assets/invalidName_phone.png',
  750: 'https://cdn.llscdn.com/sprout/assets/invalidName_phone@2x.png',
  1125: 'https://cdn.llscdn.com/sprout/assets/invalidName_phone@3x.png',
  height: "".concat(62 / PHONE_RATIO, "rem")
}];
var PAD_IMAGE = [{
  1024: 'https://cdn.llscdn.com/sprout/assets/invalidName_pad.png',
  2048: 'https://cdn.llscdn.com/sprout/assets/invalidName_pad@2x.png',
  3072: 'https://cdn.llscdn.com/sprout/assets/invalidName_pad@3x.png',
  height: "".concat(68 / PAD_RATIO, "rem")
}];
function PageLoading(props) {
  var _ref = props || {},
      _ref$isPad = _ref.isPad,
      isPad = _ref$isPad === void 0 ? false : _ref$isPad,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className;

  return React__default.createElement("div", {
    className: classnames('ph-page-loading', className, {
      'is-pad': isPad
    })
  }, React__default.createElement(Imager, {
    className: "loading-image",
    isPad: isPad,
    imgList: isPad ? PAD_IMAGE : PHONE_IMAGE
  }), React__default.createElement("div", {
    className: "loading-text"
  }, "\u52AA\u529B\u52A0\u8F7D\u4E2D"));
}
function index (props) {
  var loadingEl;
  return {
    show: function show() {
      var div = document.createElement('div');
      document.body.appendChild(div);
      ReactDOM.render(React__default.createElement(PageLoading, _extends({}, props)), div);
      loadingEl = div;
    },
    hide: function hide() {
      if (loadingEl) document.body.removeChild(loadingEl);
      loadingEl = null;
    }
  };
}

export default index;
export { PageLoading };
