import classnames from 'classnames';
import React, { PureComponent } from 'react';
import 'fontfaceobserver';

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

// tslint:disable-next-line
var PHONE_RATIO = 37.5;
var PAD_RATIO = 102.4;

var loadImage = function loadImage(imgSrc) {
  return new Promise(function (resolve, reject) {
    var img = new Image();
    img.src = imgSrc;

    img.onload = function () {
      resolve();
    };

    img.onerror = function () {
      reject();
    };
  });
};

function getDPR() {
  var dpr = Math.floor(window.devicePixelRatio) || 1;
  if (dpr > 3) dpr = 3;
  if (dpr < 1) dpr = 1;
  return dpr;
}

var Picture =
/*#__PURE__*/
function (_PureComponent) {
  _inherits(Picture, _PureComponent);

  function Picture() {
    var _this;

    _classCallCheck(this, Picture);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Picture).apply(this, arguments));
    _this.container = null;
    _this.dpr = getDPR();
    return _this;
  }

  _createClass(Picture, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.initImage();
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.container = null;
    }
  }, {
    key: "initImage",
    value: function initImage() {
      var _this2 = this;

      var _this$props = this.props,
          img = _this$props.img,
          list = _this$props.list,
          onSuccess = _this$props.onSuccess,
          onFailure = _this$props.onFailure;
      var imgList = img ? [img] : list;
      var sequence = Promise.resolve();
      imgList.forEach(function (listItem, index) {
        sequence = sequence.then(function () {
          return _this2.createImage(listItem, index);
        });
      });
      sequence.then(onSuccess, onFailure);
    }
  }, {
    key: "createImage",
    value: function createImage(listItem, index) {
      var dpr = this.dpr,
          props = this.props,
          container = this.container;
      var onClick = props.onClick,
          useDivInner = props.useDivInner,
          pxToRem = props.pxToRem,
          isPad = props.isPad,
          superWidth = props.width,
          replace = props.replace;
      var itemWidth = listItem.width,
          height = listItem.height,
          divInner = listItem.divInner,
          src = listItem.src;
      var isDivInner = typeof divInner === 'undefined' ? useDivInner : divInner;
      var ratio = isPad ? PAD_RATIO : PHONE_RATIO;
      var heightString = pxToRem ? "".concat(height / ratio, "rem") : "".concat(height, "px");
      var width = itemWidth || superWidth;
      var widthString = width && pxToRem ? "".concat(width / ratio, "rem") : "".concat(width, "px");
      return new Promise(function (resolve, reject) {
        if (!container) return;
        var box = document.createElement('div');
        box.className = 'imager-container';
        box.style.height = heightString;
        if (widthString) box.style.width = widthString;
        container.appendChild(box);

        if (onClick) {
          box.addEventListener('click', function (event) {
            onClick(event, listItem, index);
          });
        }

        var nodeType = isDivInner ? 'div' : 'img';
        var imgEl = document.createElement(nodeType);
        imgEl.className = 'imager-inner';
        var resource = new Image();
        var miniImg = "".concat(src, "?imageView2/2/h/").concat(height);
        var suitableImg = dpr === 3 ? src : "".concat(src, "?imageView2/2/h/").concat(height * dpr);

        resource.onload = function () {
          box.style.backgroundImage = "url(".concat(miniImg, ")");
          var suitableImgLoader = replace ? loadImage(suitableImg) : Promise.resolve({});
          suitableImgLoader.then(function () {
            if (isDivInner) {
              imgEl.style.backgroundImage = "url(".concat(suitableImg, ")");
            } else {
              var el = imgEl;
              el.src = suitableImg;
              el.style.height = heightString;
              if (widthString) el.style.width = widthString;
            }

            if (box) box.appendChild(imgEl);
            if (replace) box.style.backgroundImage = '';
          });
          resolve();
        };

        resource.onerror = function (err) {
          reject(err);
        };

        resource.src = miniImg;
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var _this$props2 = this.props,
          className = _this$props2.className,
          isPad = _this$props2.isPad;
      return React.createElement("div", {
        ref: function ref(el) {
          return _this3.container = el;
        },
        className: classnames('ph-picture', className, {
          'is-pad': isPad
        })
      });
    }
  }]);

  return Picture;
}(PureComponent);
Picture.defaultProps = {
  pxToRem: true
};

export default Picture;
